<?php
/**
* 2007-2018 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2018 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_')) {
    exit;
}

include_once('classes/avsbannerblock_image_upload.class.php');
include_once('classes/avsbannerblock_status.class.php');

class AvsBannerBlock extends Module
{
    protected $config_form = false;
    public $n = 2;
    public function __construct()
    {
        $this->name = 'avsbannerblock';
        $this->version = '1.0.0';
        $this->author = 'AVS Templates';
        $this->bootstrap = true;
        $this->need_instance = 0;

        parent::__construct();

        $this->displayName = $this->l('AVS - Banner Block');
        $this->description = $this->l('Adds custom information blocks in your store.');

        $this->ps_versions_compliancy = array('min' => '1.7.0.0', 'max' => _PS_VERSION_);
    }

    public function install()
    {
        $this->defineVariable();

        return parent::install() &&
            $this->registerHook('displayBottomColumn');
    }

    public function defineVariable()
    {
        $result = array();
        $languages = Language::getLanguages();

        for ($i=1; $i<=$this->n; $i++) {
            foreach ($languages as $lang) {
                $result['AVSBANNERBLOCK_IMAGE_NAME_'.$i][$lang['id_lang']] = 'banner_'.$i.'.jpg';

                $result['AVSBANNERBLOCK_LINK_'.$i][$lang['id_lang']] = '#';
            }
            $tmp = $result['AVSBANNERBLOCK_IMAGE_NAME_'.$i];
            Configuration::updateValue('AVSBANNERBLOCK_IMAGE_NAME_'.$i, $tmp);

            Configuration::updateValue('AVSBANNERBLOCK_LINK_'.$i, $result['AVSBANNERBLOCK_LINK_'.$i]);
        }
    }

    public function uninstall()
    {
        for ($i=1; $i<=$this->n; $i++) {
            Configuration::deleteByName('AVSBANNERBLOCK_IMAGE_NAME_'.$i);
            Configuration::deleteByName('AVSBANNERBLOCK_LINK_'.$i);
        }
        return parent::uninstall();
    }

    public function getContent()
    {
        $messages = '';
        $result = array();
        $img = '';
        $notic = '';
        if (((bool)Tools::isSubmit('submitavsbannerblock')) == true) {
            for ($i=1; $i<=$this->n; $i++) {
                $languages = Language::getLanguages();
                foreach ($languages as $lang) {
                    $img = 'AVSBANNERBLOCK_IMAGE_NAME_'.$i.'_'.$lang['id_lang'];

                    if (!empty($_FILES[$img]['name'])) {
                        $this->tvcmsobj = new AvsBannerBlockImageUpload();
                        $old_file = Configuration::get('AVSBANNERBLOCK_IMAGE_NAME_'.$i, $lang['id_lang']);
                        $result = $this->tvcmsobj->imageUploading($_FILES[$img], $old_file);

                        if ($result['success']) {
                            $notic = $this->l('Image  '.$i.' is Save'." in ".$lang['name'].'.');
                            $messages .= $this->displayConfirmation($notic);

                            $result['AVSBANNERBLOCK_IMAGE_NAME_'.$i][$lang['id_lang']] = $result['name'];
                        } else {
                            $notic = $this->l("Image Upload Problem in Image ".$i." in ".$lang['name'].'.');
                            $messages .= $this->displayError($notic);
                            $name = Configuration::get('AVSBANNERBLOCK_IMAGE_NAME_'.$i, $lang['id_lang']);
                            $result['AVSBANNERBLOCK_IMAGE_NAME_'.$i][$lang['id_lang']] = $name;
                        }
                    }

                    $a = Tools::getValue('AVSBANNERBLOCK_LINK_'.$i.'_'.$lang['id_lang']);
                    $result['AVSBANNERBLOCK_LINK_'.$i][$lang['id_lang']] = $a;
                }

                $tmp = $result['AVSBANNERBLOCK_IMAGE_NAME_'.$i];
                Configuration::updateValue('AVSBANNERBLOCK_IMAGE_NAME_'.$i, $tmp);

                Configuration::updateValue('AVSBANNERBLOCK_LINK_'.$i, $result['AVSBANNERBLOCK_LINK_'.$i]);
                $messages .= $this->displayConfirmation($this->l("Record is Save in Number ".$i));
            }
        }
        $this->context->smarty->assign("total_image", $this->n);
        $output =   $messages.
                    $this->renderForm();

        return $output;
    }

    
    protected function renderForm()
    {
        $helper = new HelperForm();

        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);

        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitavsbannerblock';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
            .'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');

        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFormValues(), /* Add values for your inputs */
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
        );

        return $helper->generateForm(array($this->getConfigForm()));
    }

    
    protected function getConfigForm()
    {
        $avscms_obj = new AvsBannerBlockStatus();
        $show_fields = $avscms_obj->fieldStatusInformation();

        $tmp = array();
        for ($i=1; $i<=$this->n; $i++) {
            $tmp[] = array(
                        'col' => 6,
                        'name' => 'AVSBANNERBLOCK_IMAGE_NAME_'.$i,
                        'type' => 'file_upload_'.$i,
                        'lang' => true,
                        'label' => $this->l('Image '.$i),
                    );

            if ($show_fields['link']) {
                $tmp[] = array(
                            'col' => 6,
                            'name' => 'AVSBANNERBLOCK_LINK_'.$i,
                            'type' => 'text',
                            'lang' => true,
                            'label' => $this->l('Link '.$i),
                            'desc' => $this->l('Enter Image Link '.$i),
                        );
            }
        }

        return array(
            'form' => array(
                'legend' => array(
                'title' => $this->l('Settings'),
                'icon' => 'icon-cogs',
                ),
                'input' => $tmp,
                'submit' => array(
                    'title' => $this->l('Save'),
                ),
            ),
        );
    }

   
    protected function getConfigFormValues()
    {
        $this->context->smarty->assign("total_image", $this->n);
        $fields = array();
        $languages = Language::getLanguages();

        for ($i=1; $i<=$this->n; $i++) {
            $path = _MODULE_DIR_.$this->name."/views/img/";
            foreach ($languages as $lang) {
                $a = Configuration::get('AVSBANNERBLOCK_IMAGE_NAME_'.$i, $lang['id_lang']);
                $fields['AVSBANNERBLOCK_IMAGE_NAME_'.$i][$lang['id_lang']] = $a;

                $a = Configuration::get('AVSBANNERBLOCK_LINK_'.$i, $lang['id_lang']);
                $fields['AVSBANNERBLOCK_LINK_'.$i][$lang['id_lang']] = $a;
            }
        }
        $this->context->smarty->assign("path", $path);
        return $fields;
    }


    public function hookDisplayHome()
    {
        return $this->showResult();
    }

    public function hookDisplayTopColumn()
    {
        return $this->showResult();
    }

    public function hookDisplayBottomColumn()
    {
        return $this->showResult();
    }

    public function hookDisplayLeftColumn()
    {
        return $this->showResult();
    }

    public function hookDisplayRightColumn()
    {
        return $this->showResult();
    }

    public function hookDisplayTop()
    {
        return $this->showResult();
    }

    public function showResult()
    {
        $data = array();
        $cookie = Context::getContext()->cookie;
        $id_lang = $cookie->id_lang;

        for ($i=1; $i<=$this->n; $i++) {
            $languages = Language::getLanguages();
            foreach ($languages as $lang) {
                $a = Configuration::get('AVSBANNERBLOCK_IMAGE_NAME_'.$i, $lang['id_lang']);
                $data['AVSBANNERBLOCK_IMAGE_NAME_'.$i][$lang['id_lang']] = $a;

                $a = Configuration::get('AVSBANNERBLOCK_LINK_'.$i, $lang['id_lang']);
                $data['AVSBANNERBLOCK_LINK_'.$i][$lang['id_lang']] = $a;
            }
        }
        $this->context->smarty->assign('language_id', $id_lang);
        $this->context->smarty->assign('data', $data);

        $output = $this->display(__FILE__, "views/templates/hook/avsbannerblock.tpl");
        return $output;
    }
}
