<?php
/**
* 2007-2018 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2018 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_')) {
    exit;
}

use PrestaShop\PrestaShop\Core\Module\WidgetInterface;
use PrestaShop\PrestaShop\Adapter\Image\ImageRetriever;
use PrestaShop\PrestaShop\Adapter\Product\PriceFormatter;
use PrestaShop\PrestaShop\Core\Product\ProductListingPresenter;
use PrestaShop\PrestaShop\Adapter\Product\ProductColorsRetriever;

class AvsDealOfTheDay extends Module implements WidgetInterface
{
    private $templateFile;
    public function __construct()
    {
        $this->name = 'avsdealoftheday';
        $this->author = 'AVS Templates';
        $this->version = '1.0.0';
        $this->need_instance = 0;
        $this->ps_versions_compliancy = array(
            'min' => '1.7.0.0',
            'max' => _PS_VERSION_
        );
        $this->bootstrap = true;
        parent::__construct();
        $this->displayName = $this->l('AVS - Deal Of The Day');
        $this->description = $this->l('Displays time based discounted products on your store.');
        $this->templateFile = 'module:avsdealoftheday/views/templates/hook/avsdealoftheday.tpl';
    }

    public function install()
    {
        $this->_clearCache('*');

        $languages = $this->context->language->getLanguages();
        $blockTitle = array();

        foreach ($languages as $lang) {
            $blockTitle[$lang['id_lang']] = 'Deal of the Day';
        }

        $success = (parent::install()
            && $this->registerHook('displayHeader')
            && $this->registerHook('actionProductAdd')
            && $this->registerHook('actionProductUpdate')
            && $this->registerHook('actionProductDelete')
            && $this->registerHook('actionObjectSpecificPriceCoreDeleteAfter')
            && $this->registerHook('actionObjectSpecificPriceCoreAddAfter')
            && $this->registerHook('actionObjectSpecificPriceCoreUpdateAfter')
            && $this->registerHook('displayBottomColumn')
            && Configuration::updateValue("AVS_DEALSOFDAY_TITLE", $blockTitle)
        );

        $this->_clearCache('*');

        return $success;
    }

    public function uninstall()
    {
        $this->_clearCache('*');
        return parent::uninstall();
    }

    public function hookActionProductAdd($params)
    {
        $this->_clearCache('*');
    }

    public function hookActionProductUpdate($params)
    {
        $this->_clearCache('*');
    }

    public function hookActionProductDelete($params)
    {
        $this->_clearCache('*');
    }

    public function hookActionObjectSpecificPriceCoreDeleteAfter($params)
    {
        $this->_clearCache('*');
    }

    public function hookActionObjectSpecificPriceCoreAddAfter($params)
    {
        $this->_clearCache('*');
    }

    public function hookActionObjectSpecificPriceCoreUpdateAfter($params)
    {
        $this->_clearCache('*');
    }

    public function _clearCache($template, $cache_id = null, $compile_id = null)
    {
        parent::_clearCache($this->templateFile);
    }

    public function getContent()
    {
        $output ='';
        $error='';
        $errors=array();
        $blockTitle = array();
        $languages = $this->context->language->getLanguages();

        if (Tools::isSubmit('submitAvsDealoftheDay')) {

            foreach ($languages as $lang) {
                $blockTitle[$lang['id_lang']] = Tools::getValue('AVS_DEALSOFDAY_TITLE_'.$lang['id_lang']);
            }

            if (isset($errors) && count($errors)) {
                $output = $this->displayError(implode('<br />', $errors));
            } else {
                Configuration::updateValue('AVS_DEALSOFDAY_TITLE', $blockTitle);
                $this->_clearCache('*');
                $output = $this->displayConfirmation($this->l('Your settings have been updated.'));
            }
        }

        return $output.$this->renderForm();
    }

    protected function renderForm()
    {
        $fields_form = array(
            'td-banner1' => array(
                'form' => array(
                    'legend' => array(
                        'title' => $this->l('Deal Of The Day Name'),
                        'icon' => 'icon-picture-o'
                    ),
                    'input' => array(
                    array(
                        'type' => 'text',
                        'label' => $this->l('Title'),
                        'name' => 'AVS_DEALSOFDAY_TITLE',
                        'lang' => true,
                    ),
                ),
                    'submit' => array(
                        'title' => $this->l('Save'),
                    ),
                )
            ),
        );

        $helper = new HelperForm();
        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ? Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;
        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitAvsDealoftheDay';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false).'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFieldsValues(),
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
        );

        return $helper->generateForm($fields_form);
    }

    public function getConfigFieldsValues()
    {
        $languages = $this->context->language->getLanguages();

        foreach ($languages as $lang) {
            $result['AVS_DEALSOFDAY_TITLE'][$lang['id_lang']] = Configuration::get('AVS_DEALSOFDAY_TITLE', $lang['id_lang']);
        }

        return $result;
    }

    protected function getCacheId($name = null)
    {
        if ($name === null) {
            $name = 'avsdealoftheday';
        }
        return parent::getCacheId($name.'|'.date('Ymd'));
    }

    public function renderWidget($hookName = null, array $configuration = array())
    {
        if ($this->context->controller->php_self == 'index') {
            if (!$this->isCached($this->templateFile, $this->getCacheId(''))) {
                $variables = $this->getWidgetVariables($hookName, $configuration);
                if (empty($variables)) {
                    return false;
                }
                $this->smarty->assign($variables);
            }
            return $this->fetch($this->templateFile, $this->getCacheId(''));
        }
    }

    public function hookdisplayHeader($params)
    {
        $this->context->controller->registerJavascript('modules-avsdealoftheday', 'modules/'.$this->name.'/views/js/avsdealoftheday.js', array('position' => 'bottom', 'priority' => 160));

    }

    public function getWidgetVariables($hookName = null, array $configuration = array())
    {
        $id_lang = (int)Context::getContext()->language->id;
        $products = $this->getSpecialDeals();
        return array(
            'products' => $products,
            'specialLink' => Context::getContext()->link->getPageLink('prices-drop'),
            'AVS_DEALSOFDAY_TITLE' => Configuration::get('AVS_DEALSOFDAY_TITLE', $id_lang),
        );
    }

    private function getSpecialDeals()
    {
        $products = Product::getPricesDrop((int)Context::getContext()->language->id, 0);
        $assembler = new ProductAssembler($this->context);
        $presenterFactory = new ProductPresenterFactory($this->context);
        $presentationSettings = $presenterFactory->getPresentationSettings();
        $presenter = new ProductListingPresenter(
            new ImageRetriever(
                $this->context->link
            ),
            $this->context->link,
            new PriceFormatter(),
            new ProductColorsRetriever(),
            $this->context->getTranslator()
        );
        $products_for_template = array();
        if (is_array($products)) {
            foreach ($products as $rawProduct) {
            	$tempProduct = '';
				if(strtotime($rawProduct['specific_prices']['to']) <= time()) {
	        		continue;
	        	}
                $tempProduct = $presenter->present(
                    $presentationSettings,
                    $assembler->assembleProduct($rawProduct),
                    $this->context->language
                );
                 $products_for_template[] = $tempProduct;
            }
        }
        $final_products_for_template = $products_for_template;
        return $final_products_for_template;
    }
}