<?php
/**
* 2007-2018 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2018 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_')) {
    exit;
}

use PrestaShop\PrestaShop\Core\Module\WidgetInterface;

include_once(dirname(__FILE__).'/src/AvsParallaxSampleData.php');
require_once _PS_MODULE_DIR_.'avsparallaxbannerblock/classes/AvsParallaxBannerInfoBlock.php';

class AvsParallaxBannerBlock extends Module implements WidgetInterface
{
    private $templateFile;

    public function __construct()
    {
        $this->name = 'avsparallaxbannerblock';
        $this->version = '1.0.0';
        $this->author = 'AVS Templates';
        $this->bootstrap = true;
        $this->need_instance = 0;

        parent::__construct();

        $this->displayName = $this->l('AVS - Parallax Banner Block');
        $this->description = $this->l('Adds a parallax banner block to your store.');

        $this->ps_versions_compliancy = array('min' => '1.7.0.0', 'max' => _PS_VERSION_);

        $this->templateFile = 'module:avsparallaxbannerblock/views/templates/hook/avsparallaxbannerblock.tpl';
    }

    public function install()
    {
        $this->installDB();

        $sample_data = new AvsParallaxSampleData();
        $sample_data->initData();
        return  parent::install() && $this->registerHook('displayTopColumn') && Configuration::updateValue('AVSPARALLAXBANNERIMG', 'parallax.jpg');
    }

    public function uninstall()
    {
        return parent::uninstall() && $this->uninstallDB() && Configuration::deleteByName('AVSPARALLAXBANNERIMG');
    }

    public function installDB()
    {
        $return = true;
        $return &= Db::getInstance()->execute('
                CREATE TABLE IF NOT EXISTS `'._DB_PREFIX_.'avsparallaxbannerinfo` (
                `id_avsparallaxbannerinfo` INT UNSIGNED NOT NULL AUTO_INCREMENT,
                `id_shop` int(10) unsigned DEFAULT NULL,
                PRIMARY KEY (`id_avsparallaxbannerinfo`)
            ) ENGINE='._MYSQL_ENGINE_.' DEFAULT CHARSET=utf8 ;'
        );

        $return &= Db::getInstance()->execute('
                CREATE TABLE IF NOT EXISTS `'._DB_PREFIX_.'avsparallaxbannerinfo_lang` (
                `id_avsparallaxbannerinfo` INT UNSIGNED NOT NULL,
                `id_lang` int(10) unsigned NOT NULL ,
                `text` text NOT NULL,
                PRIMARY KEY (`id_avsparallaxbannerinfo`, `id_lang`)
            ) ENGINE='._MYSQL_ENGINE_.' DEFAULT CHARSET=utf8 ;'
        );

        return $return;
    }

    public function uninstallDB($drop_table = true)
    {
        $ret = true;
        if ($drop_table) {
            $ret &=  Db::getInstance()->execute('DROP TABLE IF EXISTS `'._DB_PREFIX_.'avsparallaxbannerinfo`') && Db::getInstance()->execute('DROP TABLE IF EXISTS `'._DB_PREFIX_.'avsparallaxbannerinfo_lang`');
        }

        return $ret;
    }

    public function getContent()
    {
        $output = '';
        $errors = array();
        if (Tools::isSubmit('saveavsparallaxbannerblock')) {
            if (!Tools::getValue('text_'.(int)Configuration::get('PS_LANG_DEFAULT'), false)) {
                $output = $this->displayError($this->l('Please fill out all fields.')) . $this-> renderParallaxBannerImageForm() 
                . $this->renderForm();
            } else {
                $update = $this->processSaveParallaxBannerInfo();

                if (!$update) {
                    $output = '<div class="alert alert-danger conf error">'
                        .$this->l('An error occurred on saving.')
                        .'</div>';
                } else {
                    $output = $this->displayConfirmation($this->l('The settings have been updated.'));
                }

                $this->_clearCache($this->templateFile);
            }
        } else if(Tools::isSubmit('submitAvsParallaxImgBlock')) {
            $id_shop = $this->context->shop->id;
            if (isset($_FILES['AVSPARALLAXBANNERIMG']) && isset($_FILES['AVSPARALLAXBANNERIMG']['tmp_name']) && 
                !empty($_FILES['AVSPARALLAXBANNERIMG']['tmp_name'])) {
                    if ($error = ImageManager::validateUpload($_FILES['AVSPARALLAXBANNERIMG'], Tools::convertBytes(ini_get('upload_max_filesize')))) {
                        $errors[] = $error;
                    } else {
                        $imageName = explode('.', $_FILES['AVSPARALLAXBANNERIMG']['name']);
                        $imageExt = $imageName[1];
                        $imageName = $imageName[0];
                        $bannerImageName = $imageName . '-' . $id_shop . '.' . $imageExt;

                        if (!move_uploaded_file($_FILES['AVSPARALLAXBANNERIMG']['tmp_name'], _PS_MODULE_DIR_ . $this->name . '/views/img/' . $bannerImageName)) {
                            $errors[] = $this->l('File upload error.');
                        } else {
                            Configuration::updateValue('AVSPARALLAXBANNERIMG', $bannerImageName);
                        }
                    }
            }

        }  elseif (Tools::isSubmit('deleteConfig')) {
            $config = Tools::getValue('deleteConfig');
            $configValue = Configuration::get('AVSPARALLAXBANNERIMG');

            if (file_exists(_PS_MODULE_DIR_ . $this->name . '/views/img/' . $configValue)) {
                unlink(_PS_MODULE_DIR_ . $this->name . '/views/img/' . $configValue);
                $output .= $this->displayConfirmation($this->l('Image Has been deleted'));
            }

            Configuration::updateValue($config, null);
        }

        return $output . $this-> renderParallaxBannerImageForm() . $this->renderForm();
    }

    public function processSaveParallaxBannerInfo()
    {
        $avsparallaxbannerinfo = new AvsParallaxBannerInfoBlock(Tools::getValue('id_avsparallaxbannerinfo', 1));

        $text = array();
        $languages = Language::getLanguages(false);
        foreach ($languages as $lang) {
            $text[$lang['id_lang']] = Tools::getValue('text_'.$lang['id_lang']);
        }

        $avsparallaxbannerinfo->text = $text;

        if (Shop::isFeatureActive() && !$avsparallaxbannerinfo->id_shop) {
            $saved = true;
            $shop_ids = Shop::getShops();
            foreach ($shop_ids as $id_shop) {
                $avsparallaxbannerinfo->id_shop = $id_shop;
                $saved &= $avsparallaxbannerinfo->add();
            }
        } else {
            $saved = $avsparallaxbannerinfo->save();
        }

        return $saved;
    }

    protected function renderForm()
    {
        $default_lang = (int)Configuration::get('PS_LANG_DEFAULT');

        $fields_form = array(
            'tinymce' => true,
            'legend' => array(
                'title' => $this->l('Parallax Banner Text'),
            ),
            'input' => array(
                'id_avsparallaxbannerinfo' => array(
                    'type' => 'hidden',
                    'name' => 'id_avsparallaxbannerinfo'
                ),
                'content' => array(
                    'type' => 'textarea',
                    'label' => $this->l('Text block'),
                    'lang' => true,
                    'name' => 'text',
                    'cols' => 40,
                    'rows' => 10,
                    'class' => 'rte',
                    'autoload_rte' => true,
                ),
            ),
            'submit' => array(
                'title' => $this->l('Save'),
            ),
            'buttons' => array(
                array(
                    'href' => AdminController::$currentIndex.'&configure='.$this->name.'&token='.Tools::getAdminTokenLite('AdminModules'),
                    'title' => $this->l('Back to list'),
                    'icon' => 'process-icon-back'
                )
            )
        );

        if (Shop::isFeatureActive() && Tools::getValue('id_avsparallaxbannerinfo') == false) {
            $fields_form['input'][] = array(
                'type' => 'shop',
                'label' => $this->l('Shop association'),
                'name' => 'checkBoxShopAsso_theme'
            );
        }


        $helper = new HelperForm();
        $helper->module = $this;
        $helper->name_controller = 'avsparallaxbannerblock';
        $helper->identifier = $this->identifier;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        foreach (Language::getLanguages(false) as $lang) {
            $helper->languages[] = array(
                'id_lang' => $lang['id_lang'],
                'iso_code' => $lang['iso_code'],
                'name' => $lang['name'],
                'is_default' => ($default_lang == $lang['id_lang'] ? 1 : 0)
            );
        }

        $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name;
        $helper->default_form_language = $default_lang;
        $helper->allow_employee_form_lang = $default_lang;
        $helper->toolbar_scroll = true;
        $helper->title = $this->displayName;
        $helper->submit_action = 'saveavsparallaxbannerblock';

        $helper->fields_value = $this->getFormValues();

        return $helper->generateForm(array(array('form' => $fields_form)));
    }

    protected function renderParallaxBannerImageForm()
    {
        $fields_form = array(
            'td-banner1' => array(
                'form' => array(
                    'legend' => array(
                        'title' => $this->l('Parallax Banner Image'),
                        'icon' => 'icon-picture-o'
                    ),
                    'input' => array(
                        array(
                            'type' => 'file',
                            'name' => 'AVSPARALLAXBANNERIMG',
                            'label' => $this->l('Banner Image'),
                            'size' => 20,
                            'required' => false,
                            'lang' => false,
                            'desc' => 'Recommended Size : 1920 x 900 px',
                        ),
                    ),
                    'submit' => array(
                        'title' => $this->l('Save'),
                    ),
                )
            ),
        );

        $helper = new HelperForm();

        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);

        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitAvsParallaxImgBlock';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
            .'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');

        $helper->fields_value['AVSPARALLAXBANNERIMG'] = Configuration::get('AVSPARALLAXBANNERIMG');

        $helper->tpl_vars = array(
            'languages' => $this->context->controller->getLanguages(),
            'imagePath' => _MODULE_DIR_ . $this->name . '/views/img/',
            'id_language' => $this->context->language->id,
        );

        return $helper->generateForm($fields_form);
    }

    public function getFormValues()
    {
        $fields_value = array();
        $id_avsparallaxbannerinfo = 1;

        foreach (Language::getLanguages(false) as $lang) {
            $avsparallaxbannerinfo = new AvsParallaxBannerInfoBlock((int)$id_avsparallaxbannerinfo);
            $fields_value['text'][(int)$lang['id_lang']] = $avsparallaxbannerinfo->text[(int)$lang['id_lang']];
        }

        $fields_value['id_avsparallaxbannerinfo'] = $id_avsparallaxbannerinfo;

        return $fields_value;
    }

    public function renderWidget($hookName = null, array $configuration = array())
    {
        if ($this->context->controller->php_self == 'index') {
            if (!$this->isCached($this->templateFile, $this->getCacheId(''))) {
                $this->smarty->assign($this->getWidgetVariables($hookName, $configuration));
            }

            return $this->fetch($this->templateFile, $this->getCacheId(''));
        }
    }

    public function getWidgetVariables($hookName = null, array $configuration = array())
    {
        $sql = 'SELECT r.`id_avsparallaxbannerinfo`, r.`id_shop`, rl.`text`
            FROM `'._DB_PREFIX_.'avsparallaxbannerinfo` r
            LEFT JOIN `'._DB_PREFIX_.'avsparallaxbannerinfo_lang` rl ON (r.`id_avsparallaxbannerinfo` = rl.`id_avsparallaxbannerinfo`)
            WHERE `id_lang` = '.(int)$this->context->language->id.' AND  `id_shop` = '.(int)$this->context->shop->id;

        

        return array(
            'avsparallaxtext' => Db::getInstance()->getRow($sql),
            'avsparallaximage'=> Configuration::get('AVSPARALLAXBANNERIMG'),
            'imagepath' => _MODULE_DIR_ . $this->name . '/views/img/',
        );
    }
}
