<?php
/**
* 2007-2018 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2018 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_')) {
	exit;
}

use PrestaShop\PrestaShop\Core\Module\WidgetInterface;

class AvsPaymentblock extends Module implements WidgetInterface
{
	private $templateFile;
	public function __construct()
	{
		$this->name = 'avspaymentblock';
		$this->tab = 'front_office_features';
		$this->version = '1.0.0';
		$this->author = 'Avs Templates';
		$this->need_instance = 0;

		$this->bootstrap = true;
		parent::__construct();

		$this->displayName = $this->l('Avs - Payment Options Block');
		$this->description = $this->l('Displays logo for payment options available on your store.');
		$this->ps_versions_compliancy = array('min' => '1.7.0.0', 'max' => _PS_VERSION_);

		$this->templateFile = 'module:avspaymentblock/views/templates/hook/avspaymentblock.tpl';
	}

	public function install()
	{
		return (
			parent::install()
            && Configuration::updateValue('AVSPAYMENTBLOCK_DISCOVER', 1)
            && Configuration::updateValue('AVSPAYMENTBLOCK_VISA', 1)
            && Configuration::updateValue('AVSPAYMENTBLOCK_GOOGLEWALLET', 1)
            && Configuration::updateValue('AVSPAYMENTBLOCK_PAYPAL', 1)
            && Configuration::updateValue('AVSPAYMENTBLOCK_MASTERCARD', 1)
            && Configuration::updateValue('AVSPAYMENTBLOCK_AMERICANEX', 1)
            && $this->registerHook('displayProductPage')
            && $this->registerHook('displayFooterBefore')
        );
	}

	public function uninstall()
	{
		return parent::uninstall()
            && Configuration::deleteByName('AVSPAYMENTBLOCK_DISCOVER')
            && Configuration::deleteByName('AVSPAYMENTBLOCK_VISA')
            && Configuration::deleteByName('AVSPAYMENTBLOCK_GOOGLEWALLET')
            && Configuration::deleteByName('AVSPAYMENTBLOCK_PAYPAL')
            && Configuration::deleteByName('AVSPAYMENTBLOCK_MASTERCARD')
            && Configuration::deleteByName('AVSPAYMENTBLOCK_AMERICANEX');
	}

	public function getContent()
    {
        $output = '';
        if (Tools::isSubmit('submitAvsPaymentBlock')) {
        	Configuration::updateValue('AVSPAYMENTBLOCK_DISCOVER', (int)(Tools::getValue('AVSPAYMENTBLOCK_DISCOVER')));
        Configuration::updateValue('AVSPAYMENTBLOCK_VISA', (int)(Tools::getValue('AVSPAYMENTBLOCK_VISA')));
        Configuration::updateValue('AVSPAYMENTBLOCK_GOOGLEWALLET', (int)(Tools::getValue('AVSPAYMENTBLOCK_GOOGLEWALLET')));
        Configuration::updateValue('AVSPAYMENTBLOCK_PAYPAL', (int)(Tools::getValue('AVSPAYMENTBLOCK_PAYPAL')));
        Configuration::updateValue('AVSPAYMENTBLOCK_MASTERCARD', (int)(Tools::getValue('AVSPAYMENTBLOCK_MASTERCARD')));
        Configuration::updateValue('AVSPAYMENTBLOCK_AMERICANEX', (int)(Tools::getValue('AVSPAYMENTBLOCK_AMERICANEX')));

        $this->_clearCache('*');
        $output .= $this->displayConfirmation($this->l('Your settings have been updated.'));
        }
        
        return  $output.$this->renderForm();
    }

    public function renderForm()
    {
        $fields_form = array(
            'form' => array(
                'legend' => array(
                    'title' => $this->l('Settings'),
                    'icon' => 'icon-cogs',
                ),
                'input' => array(
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Show Discover'),
                        'name' => 'AVSPAYMENTBLOCK_DISCOVER',
                        'class' => 'fixed-width-xs',
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled'),
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled'),
                            ),
                        ),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Show Visa'),
                        'name' => 'AVSPAYMENTBLOCK_VISA',
                        'class' => 'fixed-width-xs',
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled'),
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled'),
                            ),
                        ),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Show GoogleWallet'),
                        'name' => 'AVSPAYMENTBLOCK_GOOGLEWALLET',
                        'class' => 'fixed-width-xs',
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled'),
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled'),
                            ),
                        ),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Show Paypal'),
                        'name' => 'AVSPAYMENTBLOCK_PAYPAL',
                        'class' => 'fixed-width-xs',
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled'),
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled'),
                            ),
                        ),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Show MasterCard'),
                        'name' => 'AVSPAYMENTBLOCK_MASTERCARD',
                        'class' => 'fixed-width-xs',
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled'),
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled'),
                            ),
                        ),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Show American Express'),
                        'name' => 'AVSPAYMENTBLOCK_AMERICANEX',
                        'class' => 'fixed-width-xs',
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled'),
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled'),
                            ),
                        ),
                    ),
                ),
                'submit' => array(
                    'title' => $this->l('Save')
                ),
            ),
        );
        $lang = new Language((int)Configuration::get('PS_LANG_DEFAULT'));
        $helper = new HelperForm();
        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->default_form_language = $lang->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ? Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;
        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitAvsPaymentBlock';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
            .'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFieldsValues(),
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
        );

        return $helper->generateForm(array($fields_form));
    }

    public function getConfigFieldsValues()
    {
        $result =  array(
            'AVSPAYMENTBLOCK_DISCOVER' => Tools::getValue('AVSPAYMENTBLOCK_DISCOVER', Configuration::get('AVSPAYMENTBLOCK_DISCOVER')),
            'AVSPAYMENTBLOCK_VISA' => Tools::getValue('AVSPAYMENTBLOCK_VISA', Configuration::get('AVSPAYMENTBLOCK_VISA')),
            'AVSPAYMENTBLOCK_GOOGLEWALLET' => Tools::getValue('AVSPAYMENTBLOCK_GOOGLEWALLET', Configuration::get('AVSPAYMENTBLOCK_GOOGLEWALLET')),
            'AVSPAYMENTBLOCK_PAYPAL' => Tools::getValue('AVSPAYMENTBLOCK_PAYPAL', Configuration::get('AVSPAYMENTBLOCK_PAYPAL')),
            'AVSPAYMENTBLOCK_MASTERCARD' => Tools::getValue('AVSPAYMENTBLOCK_MASTERCARD', Configuration::get('AVSPAYMENTBLOCK_MASTERCARD')),
            'AVSPAYMENTBLOCK_AMERICANEX' => Tools::getValue('AVSPAYMENTBLOCK_AMERICANEX', Configuration::get('AVSPAYMENTBLOCK_AMERICANEX')),
        );
        return $result;
    }

	public function renderWidget($hookName = null, array $configuration = array())
    {
		if (!$this->isCached($this->templateFile, $this->getCacheId(''))) {
            
            $variables = $this->getWidgetVariables($hookName, $configuration);

            if (empty($variables)) {
                return false;
            }

            $this->smarty->assign($variables);
        }
        return $this->fetch($this->templateFile, $this->getCacheId(''));
    }

    public function getWidgetVariables($hookName = null, array $configuration = array())
    {
        if (Configuration::get('PS_CATALOG_MODE')) {
			return;
        }

        return array(
            'path' => _MODULE_DIR_ . $this->name,
            'discover' => Configuration::get('AVSPAYMENTBLOCK_DISCOVER'),
            'visa' => Configuration::get('AVSPAYMENTBLOCK_VISA'),
            'googlewallet' => Configuration::get('AVSPAYMENTBLOCK_GOOGLEWALLET'),
            'paypal' => Configuration::get('AVSPAYMENTBLOCK_PAYPAL'),
            'mastercard' => Configuration::get('AVSPAYMENTBLOCK_MASTERCARD'),
            'americanex' => Configuration::get('AVSPAYMENTBLOCK_AMERICANEX'),
        );
    }
}


