<?php
/**
* 2007-2018 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2018 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_')) {
    exit;
}

use PrestaShop\PrestaShop\Core\Module\WidgetInterface;
use PrestaShop\PrestaShop\Adapter\Category\CategoryProductSearchProvider;
use PrestaShop\PrestaShop\Adapter\Image\ImageRetriever;
use PrestaShop\PrestaShop\Adapter\Product\PriceFormatter;
use PrestaShop\PrestaShop\Core\Product\ProductListingPresenter;
use PrestaShop\PrestaShop\Adapter\Product\ProductColorsRetriever;
use PrestaShop\PrestaShop\Adapter\BestSales\BestSalesProductSearchProvider;
use PrestaShop\PrestaShop\Core\Product\Search\ProductSearchContext;
use PrestaShop\PrestaShop\Core\Product\Search\ProductSearchQuery;
use PrestaShop\PrestaShop\Core\Product\Search\SortOrder;

class AvsProductstab extends Module implements WidgetInterface
{
    private $templateFile;
    public function __construct()
    {
        $this->name = 'avsproductstab';
        $this->version = '1.0.0';
        $this->author = 'AVS Templates';
        $this->need_instance = 0;
        $this->ps_versions_compliancy = array(
            'min' => '1.7.0.0',
            'max' => _PS_VERSION_,
        );
        $this->bootstrap = true;
        parent::__construct();

        $this->displayName = $this->l('AVS - Products Tab');
        $this->description = $this->l('Displays Products tab as Grid or Slider');
        $this->templateFile = 'module:avsproductstab/views/templates/hook/avsproductstab.tpl';
    }

    public function install()
    {
        $this->_clearCache('*');

           return parent::install()
            && Configuration::updateValue('AVSPRODUCTSBLOCK_NEW', 1)
            && Configuration::updateValue('AVSPRODUCTSBLOCK_FEATURED', 1)
            && Configuration::updateValue('AVSPRODUCTSBLOCK_BEST', 1)
            && Configuration::updateValue('AVSPRODUCTSBLOCK_SPECIAL', 0)
            && Configuration::updateValue('AVSPRODUCTSBLOCK_IMGCHANGE', 1)
            && Configuration::updateValue('AVSPRODUCTSBLOCK_NBR', 10)
            && Configuration::updateValue('AVSPRODUCTSBLOCK_ROWS', 2)
            && Configuration::updateValue('AVSPRODUCTSBLOCK_COLUMNSMOBILE', 1)
            && Configuration::updateValue('AVSPRODUCTSBLOCK_COLUMNSTABLET', 2)
            && Configuration::updateValue('AVSPRODUCTSBLOCK_COLUMNSLAPTOP', 3)
            && Configuration::updateValue('AVSPRODUCTSBLOCK_COLUMNSDESKTOP', 4)
            && $this->registerHook('actionProductAdd')
            && $this->registerHook('actionProductUpdate')
            && $this->registerHook('actionProductDelete')
            && $this->registerHook('categoryUpdate')
            && $this->registerHook('actionOrderStatusPostUpdate')
            && $this->registerHook('displayTopColumn')
            && $this->registerHook('displayHeader')
            && ProductSale::fillProductSales();
    }

    public function uninstall()
    {
        $this->_clearCache('*');

        return parent::uninstall()
            && Configuration::deleteByName('AVSPRODUCTSBLOCK_NEW')
            && Configuration::deleteByName('AVSPRODUCTSBLOCK_FEATURED')
            && Configuration::deleteByName('AVSPRODUCTSBLOCK_BEST')
            && Configuration::deleteByName('AVSPRODUCTSBLOCK_SPECIAL')
            && Configuration::deleteByName('AVSPRODUCTSBLOCK_IMGCHANGE')
            && Configuration::deleteByName('AVSPRODUCTSBLOCK_NBR')
            && Configuration::deleteByName('AVSPRODUCTSBLOCK_ROWS')
            && Configuration::deleteByName('AVSPRODUCTSBLOCK_COLUMNSMOBILE')
            && Configuration::deleteByName('AVSPRODUCTSBLOCK_COLUMNSTABLET')
            && Configuration::deleteByName('AVSPRODUCTSBLOCK_COLUMNSLAPTOP')
            && Configuration::deleteByName('AVSPRODUCTSBLOCK_COLUMNSDESKTOP');
    }

    public function hookActionProductAdd($params)
    {
        $this->_clearCache('*');
    }

    public function hookActionProductUpdate($params)
    {
        $this->_clearCache('*');
    }

    public function hookActionProductDelete($params)
    {
        $this->_clearCache('*');
    }

    public function hookCategoryUpdate($params)
    {
        $this->_clearCache('*');
    }

    public function hookActionOrderStatusPostUpdate($params)
    {
        $this->_clearCache('*');
    }

    public function _clearCache($template, $cache_id = null, $compile_id = null)
    {
        parent::_clearCache($this->templateFile);
    }

    public function getContent()
    {
        $output = '';
        $errors = array();

        if (Tools::isSubmit('submitAvsProductstabModule')) {
            $nbr = (int)Tools::getValue('AVSPRODUCTSBLOCK_NBR');
            $rownbr = (int)Tools::getValue('AVSPRODUCTSBLOCK_ROWS');
            $colnbrmmobile = (int)Tools::getValue('AVSPRODUCTSBLOCK_COLUMNSMOBILE');
            $colnbrtablet = (int)Tools::getValue('AVSPRODUCTSBLOCK_COLUMNSTABLET');
            $colnbrlaptop = (int)Tools::getValue('AVSPRODUCTSBLOCK_COLUMNSLAPTOP');
            $colnbrdesktop = (int)Tools::getValue('AVSPRODUCTSBLOCK_COLUMNSDESKTOP');

            if (!$nbr || $nbr <= 0 || !Validate::isInt($nbr)) {
                $errors[] = $this->l('An invalid number of products has been specified.');
            }

            if (!$rownbr || $rownbr <= 0 || $rownbr > 3 || !Validate::isInt($rownbr)) {
                $errors[] = $this->l('An invalid number of rows has been specified.');
            }


            if (!$colnbrmmobile || $colnbrmmobile <= 0 || !Validate::isInt($colnbrmmobile)) {
                $errors[] = $this->l('An invalid number of columns has been specified for mobile.');
            }

            if (!$colnbrtablet || $colnbrtablet <= 0 || !Validate::isInt($colnbrtablet)) {
                $errors[] = $this->l('An invalid number of columns has been specified for tablet.');
            }

            if (!$colnbrlaptop || $colnbrlaptop <= 0 || !Validate::isInt($colnbrlaptop)) {
                $errors[] = $this->l('An invalid number of columns has been specified for laptop.');
            }

            if (!$colnbrdesktop || $colnbrdesktop <= 0 || !Validate::isInt($colnbrdesktop)) {
                $errors[] = $this->l('An invalid number of columns has been specified for desktop.');
            }

            if (isset($errors) && count($errors)) {
                $output = $this->displayError(implode('<br />', $errors));
            } else {
                Configuration::updateValue('AVSPRODUCTSBLOCK_NEW', (int)(Tools::getValue('AVSPRODUCTSBLOCK_NEW')));
                Configuration::updateValue('AVSPRODUCTSBLOCK_FEATURED', (int)(Tools::getValue('AVSPRODUCTSBLOCK_FEATURED')));
                Configuration::updateValue('AVSPRODUCTSBLOCK_BEST', (int)(Tools::getValue('AVSPRODUCTSBLOCK_BEST')));
                Configuration::updateValue('AVSPRODUCTSBLOCK_SPECIAL', (int)(Tools::getValue('AVSPRODUCTSBLOCK_SPECIAL')));
                Configuration::updateValue('AVSPRODUCTSBLOCK_IMGCHANGE', (int)(Tools::getValue('AVSPRODUCTSBLOCK_IMGCHANGE')));
                Configuration::updateValue('AVSPRODUCTSBLOCK_NBR', (int)($nbr));
                Configuration::updateValue('AVSPRODUCTSBLOCK_ROWS', (int)($rownbr));
                Configuration::updateValue('AVSPRODUCTSBLOCK_COLUMNSMOBILE', (int)($colnbrmmobile));
                Configuration::updateValue('AVSPRODUCTSBLOCK_COLUMNSTABLET', (int)($colnbrtablet));
                Configuration::updateValue('AVSPRODUCTSBLOCK_COLUMNSLAPTOP', (int)($colnbrlaptop));
                Configuration::updateValue('AVSPRODUCTSBLOCK_COLUMNSDESKTOP', (int)($colnbrdesktop));
                $this->_clearCache('*');
            $output .= $this->displayConfirmation($this->l('Your settings have been updated.'));
            }
        } 
    return $output.$this->renderForm();
    }

    public function renderForm()
    {
        $fields_form = array(
            'form' => array(
                'legend' => array(
                    'title' => $this->l('Settings'),
                    'icon' => 'icon-cogs',
                ),
                'input' => array(
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Show New Products'),
                        'name' => 'AVSPRODUCTSBLOCK_NEW',
                        'class' => 'fixed-width-xs',
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled'),
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled'),
                            ),
                        ),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Show Featured Products'),
                        'name' => 'AVSPRODUCTSBLOCK_FEATURED',
                        'class' => 'fixed-width-xs',
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled'),
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled'),
                            ),
                        ),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Show Best Seller Products'),
                        'name' => 'AVSPRODUCTSBLOCK_BEST',
                        'class' => 'fixed-width-xs',
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled'),
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled'),
                            ),
                        ),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Show Special Products'),
                        'name' => 'AVSPRODUCTSBLOCK_SPECIAL',
                        'class' => 'fixed-width-xs',
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled'),
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled'),
                            ),
                        ),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Change product image on hover'),
                        'name' => 'AVSPRODUCTSBLOCK_IMGCHANGE',
                        'class' => 'fixed-width-xs',
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled'),
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled'),
                            ),
                        ),
                    ),
                    array(
                        'col' => 2,
                        'type' => 'text',
                        'label' => $this->l('Max Products to display'),
                        'name' => 'AVSPRODUCTSBLOCK_NBR',
                        'class' => 'fixed-width-xs',
                    ),
                    array(
                        'col' => 2,
                        'type' => 'text',
                        'label' => $this->l('Max Products rows'),
                        'name' => 'AVSPRODUCTSBLOCK_ROWS',
                        'class' => 'fixed-width-xs',
                        'desc' => $this->l('Maximum 3 rows can be added to the block'),
                    ),
                    array(
                        'col' => 2,
                        'type' => 'text',
                        'label' => $this->l('Max Products columns for Mobile View'),
                        'name' => 'AVSPRODUCTSBLOCK_COLUMNSMOBILE',
                        'class' => 'fixed-width-xs',
                    ),
                    array(
                        'col' => 2,
                        'type' => 'text',
                        'label' => $this->l('Max Products columns for Tablet View'),
                        'name' => 'AVSPRODUCTSBLOCK_COLUMNSTABLET',
                        'class' => 'fixed-width-xs',
                    ),
                    array(
                        'col' => 2,
                        'type' => 'text',
                        'label' => $this->l('Max Products columns for Laptop View'),
                        'name' => 'AVSPRODUCTSBLOCK_COLUMNSLAPTOP',
                        'class' => 'fixed-width-xs',
                    ),
                    array(
                        'col' => 2,
                        'type' => 'text',
                        'label' => $this->l('Max Products columns for Desktop View'),
                        'name' => 'AVSPRODUCTSBLOCK_COLUMNSDESKTOP',
                        'class' => 'fixed-width-xs',
                    ),
                ),
                'submit' => array(
                    'title' => $this->l('Save')
                ),
            ),
        );
        $lang = new Language((int)Configuration::get('PS_LANG_DEFAULT'));
        $helper = new HelperForm();
        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->default_form_language = $lang->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ? Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;
        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitAvsProductstabModule';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
            .'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFieldsValues(),
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
        );

        return $helper->generateForm(array($fields_form));
    }

    public function getConfigFieldsValues()
    {
        $result =  array(
            'AVSPRODUCTSBLOCK_NEW' => Tools::getValue('AVSPRODUCTSBLOCK_NEW', Configuration::get('AVSPRODUCTSBLOCK_NEW')),
            'AVSPRODUCTSBLOCK_FEATURED' => Tools::getValue('AVSPRODUCTSBLOCK_FEATURED', Configuration::get('AVSPRODUCTSBLOCK_FEATURED')),
            'AVSPRODUCTSBLOCK_BEST' => Tools::getValue('AVSPRODUCTSBLOCK_BEST', Configuration::get('AVSPRODUCTSBLOCK_BEST')),
            'AVSPRODUCTSBLOCK_SPECIAL' => Tools::getValue('AVSPRODUCTSBLOCK_SPECIAL', Configuration::get('AVSPRODUCTSBLOCK_SPECIAL')),
            'AVSPRODUCTSBLOCK_IMGCHANGE' => Tools::getValue('AVSPRODUCTSBLOCK_IMGCHANGE', Configuration::get('AVSPRODUCTSBLOCK_IMGCHANGE')),
            'AVSPRODUCTSBLOCK_NBR' => Tools::getValue('AVSPRODUCTSBLOCK_NBR', Configuration::get('AVSPRODUCTSBLOCK_NBR')),
            'AVSPRODUCTSBLOCK_ROWS' => Tools::getValue('AVSPRODUCTSBLOCK_ROWS', Configuration::get('AVSPRODUCTSBLOCK_ROWS')),
            'AVSPRODUCTSBLOCK_COLUMNSMOBILE' => Tools::getValue('AVSPRODUCTSBLOCK_COLUMNSMOBILE', Configuration::get('AVSPRODUCTSBLOCK_COLUMNSMOBILE')),
            'AVSPRODUCTSBLOCK_COLUMNSTABLET' => Tools::getValue('AVSPRODUCTSBLOCK_COLUMNSTABLET', Configuration::get('AVSPRODUCTSBLOCK_COLUMNSTABLET')),
            'AVSPRODUCTSBLOCK_COLUMNSLAPTOP' => Tools::getValue('AVSPRODUCTSBLOCK_COLUMNSLAPTOP', Configuration::get('AVSPRODUCTSBLOCK_COLUMNSLAPTOP')),
            'AVSPRODUCTSBLOCK_COLUMNSDESKTOP' => Tools::getValue('AVSPRODUCTSBLOCK_COLUMNSDESKTOP', Configuration::get('AVSPRODUCTSBLOCK_COLUMNSDESKTOP')),
        );

        return $result;
    }

    public function renderWidget($hookName, array $configuration)
    {
        if ($this->context->controller->php_self == 'index') {
            if (!$this->isCached($this->templateFile, $this->getCacheId(''))) {
                $variables = $this->getWidgetVariables($hookName, $configuration);
                if (empty($variables)) {
                    return false;
                }
                $this->smarty->assign($variables);
            }
            return $this->fetch($this->templateFile, $this->getCacheId(''));
        }
    }

    public function hookdisplayHeader($params)
    {
        $this->context->controller->registerJavascript('modules-avsproductsblock', 'modules/'.$this->name.'/views/js/avsproductstab.js', array('position' => 'bottom', 'priority' => 141));
        Media::addJsDef(array('avsproductsblock' => array(
            'columnsmobile' => Configuration::get('AVSPRODUCTSBLOCK_COLUMNSMOBILE'),
            'columnstablet' => Configuration::get('AVSPRODUCTSBLOCK_COLUMNSTABLET'),
            'columnslaptop' => Configuration::get('AVSPRODUCTSBLOCK_COLUMNSLAPTOP'),
            'columnsdesktop' => Configuration::get('AVSPRODUCTSBLOCK_COLUMNSDESKTOP')
        )));
    }

    public function getWidgetVariables($hookName, array $configuration)
    {
        $newProducts = $this->getNewProducts();
        $specialProducts = $this->getSpecialProducts();
        $bestSeller = $this->getBestSellers();
        $featureProduct = $this->getFeaturedProducts();

        if(!$newProducts) $newProducts = null;
        if(!$bestSeller) $bestSeller = null;
        if(!$specialProducts) $specialProducts = null;
        
        $avsproductblock = array();
        if(Configuration::get('AVSPRODUCTSBLOCK_FEATURED')) {
            $avsproductblock[] = array('id' => 'featured_product', 'name' => $this->l('Featured'), 'productInfo' => $featureProduct);
        }
        if(Configuration::get('AVSPRODUCTSBLOCK_NEW')) {
            $avsproductblock[] = array('id' => 'new_product', 'name' => $this->l('New Arrival'), 'productInfo' => $newProducts);
        }
        if(Configuration::get('AVSPRODUCTSBLOCK_SPECIAL')) {
            $avsproductblock[] = array('id' => 'special_product', 'name' => $this->l('Specials'), 'productInfo' => $specialProducts);
        }
        if(Configuration::get('AVSPRODUCTSBLOCK_BEST')) {
            $avsproductblock[] = array('id' => 'bestseller_product', 'name' => $this->l('Best seller'), 'productInfo' => $bestSeller);
        }

        return array(
            'avsproductblock' => $avsproductblock,
            'no_prod' => (int)Configuration::get('AVSPRODUCTSBLOCK_NBR'),
            'productrows' => Configuration::get('AVSPRODUCTSBLOCK_ROWS'),
            'imgchange' => Configuration::get('AVSPRODUCTSBLOCK_IMGCHANGE'),
        );
    }

    protected function getFeaturedProducts()
    {
        $category = new Category(Context::getContext()->shop->getCategory(), (int)Context::getContext()->language->id);
        $nb = (int)Configuration::get('AVSPRODUCTSBLOCK_NBR');
        $result = $category->getProducts((int) $this->context->language->id, 1, ($nb ? $nb : 8), 'position');

        $assembler = new ProductAssembler($this->context);
        $presenterFactory = new ProductPresenterFactory($this->context);
        $presentationSettings = $presenterFactory->getPresentationSettings();
        $presenter = new ProductListingPresenter(
            new ImageRetriever(
                $this->context->link
            ),
            $this->context->link,
            new PriceFormatter(),
            new ProductColorsRetriever(),
            $this->context->getTranslator()
        );
        $products_for_template = array();
        foreach ($result as $rawProduct) {
            $products_for_template[] = $presenter->present(
                $presentationSettings,
                $assembler->assembleProduct($rawProduct),
                $this->context->language
            );
        }
        return $products_for_template;
    }

    protected function getNewProducts()
    {
        if (Configuration::get('PS_CATALOG_MODE')) {
            return false;
        }

        $newProducts = false;
        $nb = Configuration::get('AVSPRODUCTSBLOCK_NBR');
        $newProducts = Product::getNewProducts((int) $this->context->language->id, 0, ($nb ? $nb : 8));

        $assembler = new ProductAssembler($this->context);
        $presenterFactory = new ProductPresenterFactory($this->context);
        $presentationSettings = $presenterFactory->getPresentationSettings();
        $presenter = new ProductListingPresenter(
            new ImageRetriever(
                $this->context->link
            ),
            $this->context->link,
            new PriceFormatter(),
            new ProductColorsRetriever(),
            $this->context->getTranslator()
        );
        $products_for_template = array();
        if (is_array($newProducts)) {
            foreach ($newProducts as $rawProduct) {
                $products_for_template[] = $presenter->present(
                    $presentationSettings,
                    $assembler->assembleProduct($rawProduct),
                    $this->context->language
                );
            }
        }
        return $products_for_template;
    }

    protected function getBestSellers()
    {
        if (Configuration::get('PS_CATALOG_MODE')) {
            return false;
        }

        $searchProvider = new BestSalesProductSearchProvider(
            $this->context->getTranslator()
        );

        $context = new ProductSearchContext($this->context);

        $query = new ProductSearchQuery();

        $nProducts = (int) Configuration::get('AVSPRODUCTSBLOCK_NBR');

        $query
            ->setResultsPerPage($nProducts)
            ->setPage(1)
        ;

        $query->setSortOrder(SortOrder::random());

        $result = $searchProvider->runQuery(
            $context,
            $query
        );

        $assembler = new ProductAssembler($this->context);

        $presenterFactory = new ProductPresenterFactory($this->context);
        $presentationSettings = $presenterFactory->getPresentationSettings();
        $presenter = new ProductListingPresenter(
            new ImageRetriever(
                $this->context->link
            ),
            $this->context->link,
            new PriceFormatter(),
            new ProductColorsRetriever(),
            $this->context->getTranslator()
        );

        $products_for_template = array();

        foreach ($result->getProducts() as $rawProduct) {
            $products_for_template[] = $presenter->present(
                $presentationSettings,
                $assembler->assembleProduct($rawProduct),
                $this->context->language
            );
        }

        return $products_for_template;
    }

    private function getSpecialProducts()
    {
        $nb = Configuration::get('AVSPRODUCTSBLOCK_NBR');
        $products = Product::getPricesDrop((int)Context::getContext()->language->id, 0, ($nb ? $nb : 8));
        $assembler = new ProductAssembler($this->context);
        $presenterFactory = new ProductPresenterFactory($this->context);
        $presentationSettings = $presenterFactory->getPresentationSettings();
        $presenter = new ProductListingPresenter(
            new ImageRetriever(
                $this->context->link
            ),
            $this->context->link,
            new PriceFormatter(),
            new ProductColorsRetriever(),
            $this->context->getTranslator()
        );
        $products_for_template = array();
        if (is_array($products)) {
            foreach ($products as $rawProduct) {
                $products_for_template[] = $presenter->present(
                    $presentationSettings,
                    $assembler->assembleProduct($rawProduct),
                    $this->context->language
                );
            }
        }
    return $products_for_template;
    }
}