<?php
/**
* 2007-2018 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2018 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_')) {
    exit;
}

use PrestaShop\PrestaShop\Core\Module\WidgetInterface;
use PrestaShop\PrestaShop\Adapter\Image\ImageRetriever;
use PrestaShop\PrestaShop\Adapter\Product\PriceFormatter;
use PrestaShop\PrestaShop\Core\Product\ProductListingPresenter;
use PrestaShop\PrestaShop\Adapter\Product\ProductColorsRetriever;

class AvsSpecialProducts extends Module implements WidgetInterface
{
    private $templateFile;
    public function __construct()
    {
        $this->name = 'avsspecialproducts';
        $this->author = 'AVS Templates';
        $this->version = '1.0.0';
        $this->need_instance = 0;
        $this->ps_versions_compliancy = array(
            'min' => '1.7.0.0',
            'max' => _PS_VERSION_
        );
        $this->bootstrap = true;
        parent::__construct();
        $this->displayName = $this->l('Avs - Special Products block');
        $this->description = $this->l('Adds a block displaying your current discounted products.');
        $this->templateFile = 'module:avsspecialproducts/views/templates/hook/avsspecialproducts.tpl';
    }

    public function install()
    {
        $this->_clearCache('*');
        
        return parent::install()
            && $this->registerHook('actionProductAdd')
            && $this->registerHook('actionProductUpdate')
            && $this->registerHook('actionProductDelete')
            && $this->registerHook('actionObjectSpecificPriceCoreDeleteAfter')
            && $this->registerHook('actionObjectSpecificPriceCoreAddAfter')
            && $this->registerHook('actionObjectSpecificPriceCoreUpdateAfter')
            && Configuration::updateValue('AVSSPECIALPRODUCTSNO', 20)
            && Configuration::updateValue('AVSSPECIALPRODUCTS_IMGCHANGE', 1)
            && Configuration::updateValue('AVSSPECIALPRODUCTS_SLIDER', 1)
            && Configuration::updateValue('AVSSPECIALPRODUCTS_ROWS', 1)
            && Configuration::updateValue('AVSSPECIALPRODUCTS_COLUMNSMOBILE', 1)
            && Configuration::updateValue('AVSSPECIALPRODUCTS_COLUMNSTABLET', 2)
            && Configuration::updateValue('AVSSPECIALPRODUCTS_COLUMNSLAPTOP', 3)
            && Configuration::updateValue('AVSSPECIALPRODUCTS_COLUMNSDESKTOP', 4)
            && $this->registerHook('displayBottomColumn')
            && $this->registerHook('displayHeader');
    }

    public function uninstall()
    {
        $this->_clearCache('*');
        return parent::uninstall()
            && Configuration::deleteByName('AVSSPECIALPRODUCTSNO')
            && Configuration::deleteByName('AVSSPECIALPRODUCTS_IMGCHANGE')
            && Configuration::deleteByName('AVSSPECIALPRODUCTS_SLIDER')
            && Configuration::deleteByName('AVSSPECIALPRODUCTS_ROWS')
            && Configuration::deleteByName('AVSSPECIALPRODUCTS_COLUMNSMOBILE')
            && Configuration::deleteByName('AVSSPECIALPRODUCTS_COLUMNSTABLET')
            && Configuration::deleteByName('AVSSPECIALPRODUCTS_COLUMNSLAPTOP')
            && Configuration::deleteByName('AVSSPECIALPRODUCTS_COLUMNSDESKTOP');
    }

    public function hookActionProductAdd($params)
    {
        $this->_clearCache('*');
    }

    public function hookActionProductUpdate($params)
    {
        $this->_clearCache('*');
    }

    public function hookActionProductDelete($params)
    {
        $this->_clearCache('*');
    }

    public function hookActionObjectSpecificPriceCoreDeleteAfter($params)
    {
        $this->_clearCache('*');
    }

    public function hookActionObjectSpecificPriceCoreAddAfter($params)
    {
        $this->_clearCache('*');
    }

    public function hookActionObjectSpecificPriceCoreUpdateAfter($params)
    {
        $this->_clearCache('*');
    }

    public function _clearCache($template, $cache_id = null, $compile_id = null)
    {
        parent::_clearCache($this->templateFile);
    }

    public function getContent()
    {
        $output = '';
        $errors = array();

        if (Tools::isSubmit('submitAvsSpecialProducts')) {
            $nbr = (int)Tools::getValue('AVSSPECIALPRODUCTSNO');
            $rownbr = (int)Tools::getValue('AVSSPECIALPRODUCTS_ROWS');
            $colnbrmmobile = (int)Tools::getValue('AVSSPECIALPRODUCTS_COLUMNSMOBILE');
            $colnbrtablet = (int)Tools::getValue('AVSSPECIALPRODUCTS_COLUMNSTABLET');
            $colnbrlaptop = (int)Tools::getValue('AVSSPECIALPRODUCTS_COLUMNSLAPTOP');
            $colnbrdesktop = (int)Tools::getValue('AVSSPECIALPRODUCTS_COLUMNSDESKTOP');

            if (!$nbr || $nbr <= 0 || !Validate::isInt($nbr)) {
                $errors[] = $this->l('An invalid number of products has been specified.');
            }

            if (!$rownbr || $rownbr <= 0 || $rownbr > 3 || !Validate::isInt($rownbr)) {
                $errors[] = $this->l('An invalid number of rows has been specified.');
            }


            if (!$colnbrmmobile || $colnbrmmobile <= 0 || !Validate::isInt($colnbrmmobile)) {
                $errors[] = $this->l('An invalid number of columns has been specified for mobile.');
            }

            if (!$colnbrtablet || $colnbrtablet <= 0 || !Validate::isInt($colnbrtablet)) {
                $errors[] = $this->l('An invalid number of columns has been specified for tablet.');
            }

            if (!$colnbrlaptop || $colnbrlaptop <= 0 || !Validate::isInt($colnbrlaptop)) {
                $errors[] = $this->l('An invalid number of columns has been specified for laptop.');
            }

            if (!$colnbrdesktop || $colnbrdesktop <= 0 || !Validate::isInt($colnbrdesktop)) {
                $errors[] = $this->l('An invalid number of columns has been specified for desktop.');
            }

            if (!$nbr || $nbr <= 0 || !Validate::isInt($nbr)) {
                $errors[] = $this->l('An invalid number of products has been specified.');
            }

            if (isset($errors) && count($errors)) {
                $output = $this->displayError(implode('<br />', $errors));
            } else {
                Configuration::updateValue('AVSSPECIALPRODUCTS_IMGCHANGE', (int)(Tools::getValue('AVSSPECIALPRODUCTS_IMGCHANGE')));
                Configuration::updateValue('AVSSPECIALPRODUCTS_SLIDER', (int)(Tools::getValue('AVSSPECIALPRODUCTS_SLIDER')));
                Configuration::updateValue('AVSSPECIALPRODUCTSNO', (int)($nbr));
                Configuration::updateValue('AVSSPECIALPRODUCTS_ROWS', (int)($rownbr));
                Configuration::updateValue('AVSSPECIALPRODUCTS_COLUMNSMOBILE', (int)($colnbrmmobile));
                Configuration::updateValue('AVSSPECIALPRODUCTS_COLUMNSTABLET', (int)($colnbrtablet));
                Configuration::updateValue('AVSSPECIALPRODUCTS_COLUMNSLAPTOP', (int)($colnbrlaptop));
                Configuration::updateValue('AVSSPECIALPRODUCTS_COLUMNSDESKTOP', (int)($colnbrdesktop));
                $this->_clearCache('*');
                $output .= $this->displayConfirmation($this->l('Your settings have been updated.'));
            }
        }
        return $output.$this->renderForm();
    }

    public function renderForm()
    {
        $fields_form = array(
            'form' => array(
                'legend' => array(
                    'title' => $this->l('Settings'),
                    'icon' => 'icon-cogs'
                ),
                'input' => array(
                    array(
                        'type' => 'text',
                        'label' => $this->l('Max Products to display'),
                        'name' => 'AVSSPECIALPRODUCTSNO',
                        'class' => 'fixed-width-xs',
                        'desc' => $this->l('Define the number of products to be displayed in this block.'),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Change product image on hover'),
                        'name' => 'AVSSPECIALPRODUCTS_IMGCHANGE',
                        'class' => 'fixed-width-xs',
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled'),
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled'),
                            ),
                        ),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Display Special Product as Slider'),
                        'name' => 'AVSSPECIALPRODUCTS_SLIDER',
                        'class' => 'fixed-width-xs',
                        'desc' => $this->l('Display Slider or Grid.(Note:Slider is working if "Number of product" is set more than 5)'),
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled'),
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled'),
                            ),
                        ),
                    ),
                    array(
                        'type' => 'text',
                        'label' => $this->l('Max Products rows'),
                        'name' => 'AVSSPECIALPRODUCTS_ROWS',
                        'class' => 'fixed-width-xs',
                        'desc' => $this->l('Maximum 3 rows can be added to the block.'),
                    ),
                    array(
                        'type' => 'text',
                        'label' => $this->l('Max Products columns for Mobile View'),
                        'name' => 'AVSSPECIALPRODUCTS_COLUMNSMOBILE',
                        'class' => 'fixed-width-xs',
                    ),
                    array(
                        'type' => 'text',
                        'label' => $this->l('Max Products columns for Tablet View'),
                        'name' => 'AVSSPECIALPRODUCTS_COLUMNSTABLET',
                        'class' => 'fixed-width-xs',
                    ),
                    array(
                        'type' => 'text',
                        'label' => $this->l('Max Products columns for Laptop View'),
                        'name' => 'AVSSPECIALPRODUCTS_COLUMNSLAPTOP',
                        'class' => 'fixed-width-xs',
                    ),
                    array(
                        'type' => 'text',
                        'label' => $this->l('Max Products columns for Desktop View'),
                        'name' => 'AVSSPECIALPRODUCTS_COLUMNSDESKTOP',
                        'class' => 'fixed-width-xs',
                    ),
                ),
                'submit' => array(
                    'title' => $this->l('Save'),
                ),
            ),
        );
        $lang = new Language((int)Configuration::get('PS_LANG_DEFAULT'));
        $helper = new HelperForm();
        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->default_form_language = $lang->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ? Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;
        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitAvsSpecialProducts';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false).'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFieldsValues(),
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id
        );
        return $helper->generateForm(array($fields_form));
    }

    public function getConfigFieldsValues()
    {
        $result =  array(
            'AVSSPECIALPRODUCTSNO' => Tools::getValue('AVSSPECIALPRODUCTSNO', Configuration::get('AVSSPECIALPRODUCTSNO')),
            'AVSSPECIALPRODUCTS_IMGCHANGE' => Tools::getValue('AVSSPECIALPRODUCTS_IMGCHANGE', Configuration::get('AVSSPECIALPRODUCTS_IMGCHANGE')),
            'AVSSPECIALPRODUCTS_SLIDER' => Tools::getValue('AVSSPECIALPRODUCTS_SLIDER', Configuration::get('AVSSPECIALPRODUCTS_SLIDER')),
            'AVSSPECIALPRODUCTS_ROWS' => Tools::getValue('AVSSPECIALPRODUCTS_ROWS', Configuration::get('AVSSPECIALPRODUCTS_ROWS')),
            'AVSSPECIALPRODUCTS_COLUMNSMOBILE' => Tools::getValue('AVSSPECIALPRODUCTS_COLUMNSMOBILE', Configuration::get('AVSSPECIALPRODUCTS_COLUMNSMOBILE')),
            'AVSSPECIALPRODUCTS_COLUMNSTABLET' => Tools::getValue('AVSSPECIALPRODUCTS_COLUMNSTABLET', Configuration::get('AVSSPECIALPRODUCTS_COLUMNSTABLET')),
            'AVSSPECIALPRODUCTS_COLUMNSLAPTOP' => Tools::getValue('AVSSPECIALPRODUCTS_COLUMNSLAPTOP', Configuration::get('AVSSPECIALPRODUCTS_COLUMNSLAPTOP')),
            'AVSSPECIALPRODUCTS_COLUMNSDESKTOP' => Tools::getValue('AVSSPECIALPRODUCTS_COLUMNSDESKTOP', Configuration::get('AVSSPECIALPRODUCTS_COLUMNSDESKTOP')),
        );
        return $result;
    }

    public function renderWidget($hookName = null, array $configuration = array())
    {
            if (!$this->isCached($this->templateFile, $this->getCacheId(''))) {
                $variables = $this->getWidgetVariables($hookName, $configuration);
                if (empty($variables)) {
                    return false;
                }
                $this->smarty->assign($variables);
            }
            return $this->fetch($this->templateFile, $this->getCacheId(''));
    }

    public function hookdisplayHeader($params)
    {
        $this->context->controller->registerJavascript('modules-avsspecialproducts', 'modules/'.$this->name.'/views/js/avsspecialproducts.js', array('position' => 'bottom', 'priority' => 144));
        Media::addJsDef(array('avsspecialproducts' => array(
            'columnsmobile' => Configuration::get('AVSSPECIALPRODUCTS_COLUMNSMOBILE'),
            'columnstablet' => Configuration::get('AVSSPECIALPRODUCTS_COLUMNSTABLET'),
            'columnslaptop' => Configuration::get('AVSSPECIALPRODUCTS_COLUMNSLAPTOP'),
            'columnsdesktop' => Configuration::get('AVSSPECIALPRODUCTS_COLUMNSDESKTOP')
        )));
    }

    public function getWidgetVariables($hookName = null, array $configuration = array())
    {
        $products = $this->getSpecialProducts();
        if (!empty($products)) {
            return array(
                'products' => $products,
                'specialLink' => Context::getContext()->link->getPageLink('prices-drop'),
                'productCount' => (int)Configuration::get('AVSSPECIALPRODUCTSNO'),
                'imgchange' => (int)Configuration::get('AVSSPECIALPRODUCTS_IMGCHANGE'),
                'slider' => (int)Configuration::get('AVSSPECIALPRODUCTS_SLIDER'),
                'productrows' => (int)Configuration::get('AVSSPECIALPRODUCTS_ROWS'),
            );
        }
        return false;
    }

    private function getSpecialProducts()
    {
        $products = Product::getPricesDrop((int)Context::getContext()->language->id, 0, (int)Configuration::get('TD_SPECIAL_PRODUCTS_NBR'));
        $assembler = new ProductAssembler($this->context);
        $presenterFactory = new ProductPresenterFactory($this->context);
        $presentationSettings = $presenterFactory->getPresentationSettings();
        $presenter = new ProductListingPresenter(
            new ImageRetriever(
                $this->context->link
            ),
            $this->context->link,
            new PriceFormatter(),
            new ProductColorsRetriever(),
            $this->context->getTranslator()
        );
        $products_for_template = array();
        if (is_array($products)) {
            foreach ($products as $rawProduct) {
                $products_for_template[] = $presenter->present(
                    $presentationSettings,
                    $assembler->assembleProduct($rawProduct),
                    $this->context->language
                );
            }
        }
        return $products_for_template;
    }
}