<?php
/**
* 2007-2018 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2018 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_')) {
    exit;
}

use PrestaShop\PrestaShop\Core\Module\WidgetInterface;

class AvsStoreInfoBlock extends Module implements WidgetInterface
{
    private $templateFile;

    private $standardConfig = '';
    private $imageConfig = '';

    public function __construct()
    {
        $this->name = 'avsstoreinfoblock';
        $this->tab = 'front_office_features';
        $this->version = '1.0.0';
        $this->author = 'AVS Templates';
        $this->ps_versions_compliancy = array(
            'min' => '1.7.0.0',
            'max' => _PS_VERSION_,
        );
        $this->need_instance = 0;
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('Avs - Store Information Block');
        $this->description = $this->l('This module will allow you to display your store information.');

        $this->templateFile = 'module:avsstoreinfoblock/views/templates/hook/avsstoreinfoblock.tpl';

        $this->defineArrays();
    }

    public function install()
    {
        return parent::install() &&
            $this->registerHook('header') &&
            $this->registerHook('displayFooterBefore') &&
            $this->createConfigs();
    }

    public function uninstall()
    {
        return parent::uninstall() &&
            $this->deleteConfigs();
    }

    private function createConfigs()
    {
        $languages = $this->context->language->getLanguages();
        $description = array();
        foreach ($languages as $lang) {
            $description[$lang['id_lang']] = 'Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industrys standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book.';
        }

        $response = Configuration::updateValue('AVSSTOREINFODESC', $description);

        $response &= Configuration::updateValue('AVSSTOREINFOLOGO', 'footer-logo.png');

        return $response;
    }

    private function deleteConfigs()
    {
        $response = Configuration::deleteByName('AVSSTOREINFODESC');

        $response &= Configuration::deleteByName('AVSSTOREINFOLOGO');

        return $response;
    }

    public function defineArrays()
    {
        $this->standardConfig = array(
            'AVSSTOREINFODESC',
        );

        $this->imageConfig = array(
            'AVSSTOREINFOLOGO',
        );
    }

    public function getContent()
    {
        $languages = $this->context->language->getLanguages();
        $id_shop = $this->context->shop->id;
        $output = '';
        $errors = array();
        $standardField ='';
        if (((bool)Tools::isSubmit('submitAvsStoreInfoBlock')) == true) {
            foreach ($this->standardConfig as $sconfig) {
                foreach ($languages as $language) {
                    if (Tools::isSubmit($sconfig . '_' . $language['id_lang'])) {
                        $standardField[$language['id_lang']] = Tools::getValue($sconfig . '_' . $language['id_lang']);
                    }
                }
                
                if (is_array($standardField) && $standardField) {
                    Configuration::updateValue($sconfig, $standardField, true);
                }

                $standardField = false;
            }

            foreach ($this->imageConfig as $iconfig) {
                if (isset($_FILES[$iconfig]) && isset($_FILES[$iconfig]['tmp_name']) && !empty($_FILES[$iconfig]['tmp_name'])) {
                    if ($error = ImageManager::validateUpload($_FILES[$iconfig], Tools::convertBytes(ini_get('upload_max_filesize')))) {
                        $errors[] = $error;
                    } else {
                        $imageName = explode('.', $_FILES[$iconfig]['name']);
                        $imageExt = $imageName[1];
                        $imageName = $imageName[0];
                        $logoImageName = $imageName . '-' . $id_shop . '.' . $imageExt;

                        if (!move_uploaded_file($_FILES[$iconfig]['tmp_name'], _PS_MODULE_DIR_ . $this->name . '/views/img/' . $logoImageName)) {
                            $errors[] = $this->l('File upload error.');
                        } else {
                            Configuration::updateValue($iconfig, $logoImageName);
                        }
                    }
                }
                continue;
                if (Tools::isSubmit($iconfig)) {
                    Configuration::updateValue($iconfig, Tools::getValue($iconfig));
                }
            }

            $output .= $this->displayConfirmation($this->l('Your settings have been updated.'));
        } elseif (Tools::isSubmit('deleteConfig')) {
            $config = Tools::getValue('deleteConfig');
            $configValue = Configuration::get($config);

            if (file_exists(_PS_MODULE_DIR_ . $this->name . '/views/img/' . $configValue)) {
                unlink(_PS_MODULE_DIR_ . $this->name . '/views/img/' . $configValue);
                $output .= $this->displayConfirmation($this->l('Image Has been deleted'));
            }

            Configuration::updateValue($config, null);
        }

        return $output.$this->renderForm();
    }

    private function renderForm()
    {
        $fields_form = array(
            'td-banner1' => array(
                'form' => array(
                    'legend' => array(
                        'title' => $this->l('Store InFormation'),
                        'icon' => 'icon-picture-o'
                    ),
                    'input' => array(
                        array(
                            'type' => 'file',
                            'name' => 'AVSSTOREINFOLOGO',
                            'label' => $this->l('Logo'),
                            'size' => 20,
                            'required' => false,
                            'lang' => false,
                            'desc' => 'Recommended Size : 68 x 50 px',
                        ),
                        array(
                            'type' => 'text',
                            'label' => $this->l('Description'),
                            'name' => 'AVSSTOREINFODESC',
                            'lang' => true,
                            'required' => false,
                        ),
                    ),
                    'submit' => array(
                        'title' => $this->l('Save'),
                    ),
                )
            ),
        );

        $languages = $this->context->language->getLanguages();

        $helper = new HelperForm();

        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);

        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitAvsStoreInfoBlock';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
            .'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');

        foreach ($this->standardConfig as $key => $standardField) {
            foreach ($languages as $lang) {
                $helper->fields_value[$standardField][$lang['id_lang']] = Tools::getValue($standardField . '_' . $lang['id_lang'], Configuration::get($standardField, $lang['id_lang']));
            }
        }

        foreach ($this->imageConfig as $key => $imageField) {
            $helper->fields_value[$imageField] = Configuration::get($imageField);
        }

        $helper->tpl_vars = array(
            'languages' => $this->context->controller->getLanguages(),
            'imagePath' => _MODULE_DIR_ . $this->name . '/views/img/',
            'id_language' => $this->context->language->id,
        );

        return $helper->generateForm($fields_form);
    }

    public function renderWidget($hookName, array $configuration)
    {
        
	    if (!$this->isCached($this->templateFile, $this->getCacheId(''))) {
	        $variables = $this->getWidgetVariables($hookName, $configuration);
	        if (empty($variables)) {
	            return false;
	        }
	        $this->smarty->assign($variables);
	    }
	    return $this->fetch($this->templateFile, $this->getCacheId(''));

    }

    public function getWidgetVariables($hookName, array $configuration)
    {
        $id_default_lang = $this->context->language->id;
        $config = array();
        
        foreach ($this->standardConfig as $configItem) {
            $config[$configItem] = Configuration::get($configItem, $id_default_lang);
        }

        foreach ($this->imageConfig as $configItem) {
            $config[$configItem] = Configuration::get($configItem);
        }
        
        $config['STORELOGOLINK'] = _MODULE_DIR_ . $this->name;
        $config['SHOPBASEURL'] = _PS_BASE_URL_.__PS_BASE_URI__;
        return $config;
    }
}
